﻿using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Threading;

namespace FilteringTest.ViewModels
{
    public class BindableBase : INotifyPropertyChanged
    {
        public SynchronizationContext Context { get; set; }

        public BindableBase()
        {
            Context = SynchronizationContext.Current;
        }

        #region INotifyPropertyChanged Membres

        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Set the value of the given property and generates the PropertyChanged event.
        /// </summary>
        /// <typeparam name="T">The type of the property</typeparam>
        /// <param name="property">The reference to the property</param>
        /// <param name="value">The value to set</param>
        /// <param name="propertyName">The name of the property</param>
        protected bool SetValue<T>(ref T property, T value, [CallerMemberName] string propertyName = null)
        {
            if (Equals(property, value))
            {
                return false;
            }

            property = value;
            NotifyPropertyChanged(propertyName);

            return true;
        }

        #endregion

        public void NotifyPropertyChanged(string propertyName)
        {
            var handler = PropertyChanged;
            if (handler != null)
            {
                if (Context != null)
                {
                    Context.Post(s => handler(this, new PropertyChangedEventArgs(propertyName)), null);
                }
                else
                {
                    handler(this, new PropertyChangedEventArgs(propertyName));
                }
            }
        }
    }
}
