﻿using System.Collections.ObjectModel;

namespace FilteringTest.ViewModels
{
    public class MainWindowViewModel : BindableBase
    {
        public MainWindowViewModel()
        {
            DataSource = new ObservableCollection<MyPool>();

            for (var i = 0; i < 10; i++)
            {
                var myPool = new MyPool
                {
                    Label = "Pool " + i
                };

                for (var j = 0; j < 10; j++)
                {
                    var myDocument = new MyDocument
                    {
                        Label = "Document" + j,
                        Parent = myPool
                    };

                    switch (j % 3)
                    {
                        case 0:
                            myDocument.Status = MyDocumentStatus.Created;
                            break;
                        case 1:
                            myDocument.Status = MyDocumentStatus.Printed;
                            break;
                        default:
                            myDocument.Status = MyDocumentStatus.Sent;
                            break;
                    }
                    myPool.MyDocuments.Add(myDocument);
                }

                DataSource.Add(myPool);
            }
        }

        private ObservableCollection<MyPool> _dataSource;
        public ObservableCollection<MyPool> DataSource
        {
            get { return _dataSource; }
            set { SetValue(ref _dataSource, value); }
        }
    }


    public class MyPool : BindableBase
    {
        private ObservableCollection<MyDocument> _myDocuments = new ObservableCollection<MyDocument>();
        public ObservableCollection<MyDocument> MyDocuments
        {
            get { return _myDocuments; }
            set { SetValue(ref _myDocuments, value); }
        }

        private string _label;
        public string Label
        {
            get { return _label; }
            set { SetValue(ref _label, value); }
        }
    }

    public class MyDocument : BindableBase
    {
        private MyDocumentStatus _status;
        public MyDocumentStatus Status
        {
            get { return _status; }
            set { SetValue(ref _status, value); }
        }

        private MyPool _parent;
        public MyPool Parent
        {
            get { return _parent; }
            set { SetValue(ref _parent, value); }
        }

        private string _label;
        public string Label
        {
            get { return _label; }
            set { SetValue(ref _label, value); }
        }
    }

    public enum MyDocumentStatus
    {
        Created = 0,
        Printed = 1,
        Sent = 2,
        Unknown = 3
    }
}
